@@ -3,7 +3,7 @@ use warnings;
 
 package Pantry::App::Command::show;
 # ABSTRACT: Implements pantry show subcommand
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Pantry::App -command;
 use autodie;
@@ -20,7 +20,7 @@ sub command_type {
 }
 
 sub valid_types {
-  return qw/node role/
+  return qw/node role environment/
 }
 
 sub _show_node {
@@ -33,9 +33,16 @@ sub _show_role {
   return $self->_show_obj($opt, 'role', $name);
 }
 
+sub _show_environment {
+  my ($self, $opt, $name) = @_;
+  return $self->_show_obj($opt, 'environment', $name);
+}
+
 sub _show_obj {
   my ($self, $opt, $type, $name) = @_;
-  my $obj = $self->_check_name($type, $name);
+  my $options;
+  $options->{env} = $opt->{env} if $opt->{env};
+  my $obj = $self->_check_name($type, $name, $options);
   my $path = $obj->path;
   if ( -e $path ) {
     print scalar read_file($path);
@@ -57,7 +64,7 @@ Pantry::App::Command::show - Implements pantry show subcommand
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
