@@ -3,12 +3,15 @@ use warnings;
 
 package Pantry::App::Command::sync;
 # ABSTRACT: Implements pantry sync subcommand
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Pantry::App -command;
 use autodie;
+use JSON 2;
+use Storable qw/dclone/;
 use Net::OpenSSH;
 use Path::Class;
+use Pantry::Model::Util qw/merge_hash dot_to_hash/;
 use File::Temp 0.22 qw/tempfile/;
 
 Net::OpenSSH->VERSION("0.56_01");
@@ -75,9 +78,38 @@ sub _sync_node {
   $ssh->rsync_put($rsync_opts, $solo_rb, "$dest_dir/solo.rb")
     or die "Could not rsync solo.rb\n";
 
-  # rsync node JSON to remote /etc/chef/node.json
+  # prepare node JSON for upload
   # XXX should really check to be sure it exists
-  my $node_json = $self->pantry->node($name)->path->stringify;
+  my ($node_fh, $node_json) = tempfile( "node.json-XXXXXX", TMPDIR => 1 );
+
+  $obj->save_as($node_json);
+
+  # XXX Chef Solo doesn't yet support environment data files, so we merge them
+  # in manually, though it doesn't quite match Chef's natural attribute
+  # precedence table.
+  # http://wiki.opscode.com/display/chef/Attributes#Attributes-Precedence
+  #
+  # When Chef Solo supports env files (in repo but not released) this won't be
+  # necessary, but we'll need to upload environment files and configure them in
+  # solo.rb
+
+  my $env = $self->pantry->environment($obj->env);
+  if ( -e $env->path ) { # if we have a data file, then merge it
+    my $base = decode_json( file($node_json)->slurp );
+    my $env_default = dclone $env->default_attributes;
+    my $env_override = dclone $env->override_attributes;
+    for my $hash ( $env_default, $env_override ) {
+      for my $k ( keys %$hash ) {
+        dot_to_hash($hash, $k, $hash->{$k});
+        delete $hash->{$k};
+      }
+    }
+    my $merged = merge_hash( merge_hash( $env_default, $base ), $env_override );
+    file($node_json)->spew( to_json( $merged, { utf8 => 1, pretty => 1 } ) );
+    say STDERR file($node_json)->slurp;
+  }
+
+  # rsync node JSON to remote /etc/chef/node.json
   $ssh->rsync_put($rsync_opts, $node_json, "$dest_dir/node.json")
     or die "Could not rsync node.json\n";
 
@@ -134,7 +166,7 @@ Pantry::App::Command::sync - Implements pantry sync subcommand
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
